@@ -11,13 +11,13 @@ const Gio = imports.gi.Gio;
 const Config = imports.misc.config;
 const FileUtils = imports.misc.fileUtils;
 
-const ExtensionType = {
+var ExtensionType = {
     SYSTEM: 1,
     PER_USER: 2
 };
 
 // Maps uuid -> metadata object
-const extensions = {};
+var extensions = {};
 
 /**
  * getCurrentExtension:
@@ -158,7 +158,7 @@ function installImporter(extension) {
     imports.searchPath = oldSearchPath;
 }
 
-const ExtensionFinder = new Lang.Class({
+var ExtensionFinder = new Lang.Class({
     Name: 'ExtensionFinder',
 
     _loadExtension: function(extensionDir, info, perUserDir) {
