@@ -27,38 +27,38 @@ const Workspace = imports.ui.workspace;
 const Params = imports.misc.params;
 const Util = imports.misc.util;
 
-const MAX_APPLICATION_WORK_MILLIS = 75;
-const MENU_POPUP_TIMEOUT = 600;
-const MAX_COLUMNS = 6;
-const MIN_COLUMNS = 4;
-const MIN_ROWS = 4;
+var MAX_APPLICATION_WORK_MILLIS = 75;
+var MENU_POPUP_TIMEOUT = 600;
+var MAX_COLUMNS = 6;
+var MIN_COLUMNS = 4;
+var MIN_ROWS = 4;
 
-const INACTIVE_GRID_OPACITY = 77;
+var INACTIVE_GRID_OPACITY = 77;
 // This time needs to be less than IconGrid.EXTRA_SPACE_ANIMATION_TIME
 // to not clash with other animations
-const INACTIVE_GRID_OPACITY_ANIMATION_TIME = 0.24;
-const FOLDER_SUBICON_FRACTION = .4;
+var INACTIVE_GRID_OPACITY_ANIMATION_TIME = 0.24;
+var FOLDER_SUBICON_FRACTION = .4;
 
-const MIN_FREQUENT_APPS_COUNT = 3;
+var MIN_FREQUENT_APPS_COUNT = 3;
 
-const INDICATORS_BASE_TIME = 0.25;
-const INDICATORS_ANIMATION_DELAY = 0.125;
-const INDICATORS_ANIMATION_MAX_TIME = 0.75;
+var INDICATORS_BASE_TIME = 0.25;
+var INDICATORS_ANIMATION_DELAY = 0.125;
+var INDICATORS_ANIMATION_MAX_TIME = 0.75;
+
+var VIEWS_SWITCH_TIME = 0.4;
+var VIEWS_SWITCH_ANIMATION_DELAY = 0.1;
 
 // Follow iconGrid animations approach and divide by 2 to animate out to
 // not annoy the user when the user wants to quit appDisplay.
 // Also, make sure we don't exceed iconGrid animation total time or
 // views switch time.
-const INDICATORS_BASE_TIME_OUT = 0.125;
-const INDICATORS_ANIMATION_DELAY_OUT = 0.0625;
-const INDICATORS_ANIMATION_MAX_TIME_OUT =
+var INDICATORS_BASE_TIME_OUT = 0.125;
+var INDICATORS_ANIMATION_DELAY_OUT = 0.0625;
+var INDICATORS_ANIMATION_MAX_TIME_OUT =
     Math.min (VIEWS_SWITCH_TIME,
               IconGrid.ANIMATION_TIME_OUT + IconGrid.ANIMATION_MAX_DELAY_OUT_FOR_ITEM);
 
-const PAGE_SWITCH_TIME = 0.3;
-
-const VIEWS_SWITCH_TIME = 0.4;
-const VIEWS_SWITCH_ANIMATION_DELAY = 0.1;
+var PAGE_SWITCH_TIME = 0.3;
 
 const SWITCHEROO_BUS_NAME = 'net.hadess.SwitcherooControl';
 const SWITCHEROO_OBJECT_PATH = '/net/hadess/SwitcherooControl';
@@ -108,7 +108,7 @@ function clamp(value, min, max) {
     return Math.max(min, Math.min(max, value));
 }
 
-const BaseAppView = new Lang.Class({
+var BaseAppView = new Lang.Class({
     Name: 'BaseAppView',
     Abstract: true,
 
@@ -219,17 +219,10 @@ const BaseAppView = new Lang.Class({
         }
 
         if (animationDirection == IconGrid.AnimationDirection.IN) {
-            let toAnimate = this._grid.actor.connect('notify::allocation', Lang.bind(this,
-                function() {
-                    this._grid.actor.disconnect(toAnimate);
-                    // We need to hide the grid temporary to not flash it
-                    // for a frame
-                    this._grid.actor.opacity = 0;
-                    Meta.later_add(Meta.LaterType.BEFORE_REDRAW,
-                                   Lang.bind(this, function() {
-                                       this._doSpringAnimation(animationDirection)
-                                  }));
-                }));
+            let id = this._grid.actor.connect('paint', () => {
+                this._grid.actor.disconnect(id);
+                this._doSpringAnimation(animationDirection);
+            });
         } else {
             this._doSpringAnimation(animationDirection);
         }
@@ -256,7 +249,7 @@ const BaseAppView = new Lang.Class({
 });
 Signals.addSignalMethods(BaseAppView.prototype);
 
-const PageIndicatorsActor = new Lang.Class({
+var PageIndicatorsActor = new Lang.Class({
     Name:'PageIndicatorsActor',
     Extends: St.BoxLayout,
 
@@ -280,7 +273,7 @@ const PageIndicatorsActor = new Lang.Class({
     }
 });
 
-const PageIndicators = new Lang.Class({
+var PageIndicators = new Lang.Class({
     Name:'PageIndicators',
 
     _init: function() {
@@ -373,7 +366,7 @@ const PageIndicators = new Lang.Class({
 });
 Signals.addSignalMethods(PageIndicators.prototype);
 
-const AllView = new Lang.Class({
+var AllView = new Lang.Class({
     Name: 'AllView',
     Extends: BaseAppView,
 
@@ -799,7 +792,7 @@ const AllView = new Lang.Class({
 });
 Signals.addSignalMethods(AllView.prototype);
 
-const FrequentView = new Lang.Class({
+var FrequentView = new Lang.Class({
     Name: 'FrequentView',
     Extends: BaseAppView,
 
@@ -873,12 +866,12 @@ const FrequentView = new Lang.Class({
     }
 });
 
-const Views = {
+var Views = {
     FREQUENT: 0,
     ALL: 1
 };
 
-const ControlsBoxLayout = Lang.Class({
+var ControlsBoxLayout = Lang.Class({
     Name: 'ControlsBoxLayout',
     Extends: Clutter.BoxLayout,
 
@@ -903,7 +896,7 @@ const ControlsBoxLayout = Lang.Class({
     }
 });
 
-const ViewStackLayout = new Lang.Class({
+var ViewStackLayout = new Lang.Class({
     Name: 'ViewStackLayout',
     Extends: Clutter.BinLayout,
     Signals: { 'allocated-size-changed': { param_types: [GObject.TYPE_INT,
@@ -919,7 +912,7 @@ const ViewStackLayout = new Lang.Class({
     }
 });
 
-const AppDisplay = new Lang.Class({
+var AppDisplay = new Lang.Class({
     Name: 'AppDisplay',
 
     _init: function() {
@@ -1084,12 +1077,14 @@ const AppDisplay = new Lang.Class({
     }
 })
 
-const AppSearchProvider = new Lang.Class({
+var AppSearchProvider = new Lang.Class({
     Name: 'AppSearchProvider',
 
     _init: function() {
         this._appSys = Shell.AppSystem.get_default();
         this.id = 'applications';
+        this.isRemoteProvider = false;
+        this.canLaunchSearch = false;
     },
 
     getResultMetas: function(apps, callback) {
@@ -1137,7 +1132,7 @@ const AppSearchProvider = new Lang.Class({
     }
 });
 
-const FolderView = new Lang.Class({
+var FolderView = new Lang.Class({
     Name: 'FolderView',
     Extends: BaseAppView,
 
@@ -1253,11 +1248,12 @@ const FolderView = new Lang.Class({
     }
 });
 
-const FolderIcon = new Lang.Class({
+var FolderIcon = new Lang.Class({
     Name: 'FolderIcon',
 
     _init: function(id, path, parentView) {
         this.id = id;
+        this.name = '';
         this._parentView = parentView;
 
         this._folder = new Gio.Settings({ schema_id: 'org.gnome.desktop.app-folders.folder',
@@ -1430,7 +1426,7 @@ const FolderIcon = new Lang.Class({
 });
 Signals.addSignalMethods(FolderIcon.prototype);
 
-const AppFolderPopup = new Lang.Class({
+var AppFolderPopup = new Lang.Class({
     Name: 'AppFolderPopup',
 
     _init: function(source, side) {
@@ -1591,7 +1587,7 @@ const AppFolderPopup = new Lang.Class({
 });
 Signals.addSignalMethods(AppFolderPopup.prototype);
 
-const AppIcon = new Lang.Class({
+var AppIcon = new Lang.Class({
     Name: 'AppIcon',
 
     _init : function(app, iconParams) {
@@ -1837,7 +1833,7 @@ const AppIcon = new Lang.Class({
 });
 Signals.addSignalMethods(AppIcon.prototype);
 
-const AppIconMenu = new Lang.Class({
+var AppIconMenu = new Lang.Class({
     Name: 'AppIconMenu',
     Extends: PopupMenu.PopupMenu,
 
