@@ -10,7 +10,7 @@ const St = imports.gi.St;
 const ExtensionUtils = imports.misc.extensionUtils;
 const Main = imports.ui.main;
 
-const ExtensionState = {
+var ExtensionState = {
     ENABLED: 1,
     DISABLED: 2,
     ERROR: 3,
@@ -26,7 +26,7 @@ const ExtensionState = {
 // Arrays of uuids
 var enabledExtensions;
 // Contains the order that extensions were enabled in.
-const extensionOrder = [];
+var extensionOrder = [];
 
 // We don't really have a class to add signals on. So, create
 // a simple dummy object, add the signal methods, and export those
@@ -34,8 +34,8 @@ const extensionOrder = [];
 var _signals = {};
 Signals.addSignalMethods(_signals);
 
-const connect = Lang.bind(_signals, _signals.connect);
-const disconnect = Lang.bind(_signals, _signals.disconnect);
+var connect = Lang.bind(_signals, _signals.connect);
+var disconnect = Lang.bind(_signals, _signals.disconnect);
 
 const ENABLED_EXTENSIONS_KEY = 'enabled-extensions';
 const DISABLE_USER_EXTENSIONS_KEY = 'disable-user-extensions';
@@ -199,7 +199,14 @@ function reloadExtension(oldExtension) {
     unloadExtension(oldExtension);
 
     // Now, recreate the extension and load it.
-    let newExtension = ExtensionUtils.createExtensionObject(uuid, dir, type);
+    let newExtension;
+    try {
+        newExtension = ExtensionUtils.createExtensionObject(uuid, dir, type);
+    } catch(e) {
+        logExtensionError(uuid, e);
+        return;
+    }
+
     loadExtension(newExtension);
 }
 
@@ -211,14 +218,21 @@ function initExtension(uuid) {
         throw new Error("Extension was not properly created. Call loadExtension first");
 
     let extensionJs = dir.get_child('extension.js');
-    if (!extensionJs.query_exists(null))
-        throw new Error('Missing extension.js');
+    if (!extensionJs.query_exists(null)) {
+        logExtensionError(uuid, new Error('Missing extension.js'));
+        return false;
+    }
 
     let extensionModule;
     let extensionState = null;
 
     ExtensionUtils.installImporter(extension);
-    extensionModule = extension.imports.extension;
+    try {
+        extensionModule = extension.imports.extension;
+    } catch(e) {
+        logExtensionError(uuid, e);
+        return false;
+    }
 
     if (extensionModule.init) {
         try {
@@ -282,20 +296,12 @@ function _onVersionValidationChanged() {
     // temporarily disable them all
     enabledExtensions = [];
     for (let uuid in ExtensionUtils.extensions)
-        try {
-            reloadExtension(ExtensionUtils.extensions[uuid]);
-        } catch(e) {
-            logExtensionError(uuid, e);
-        }
+        reloadExtension(ExtensionUtils.extensions[uuid]);
     enabledExtensions = getEnabledExtensions();
 
     if (Main.sessionMode.allowExtensions) {
         enabledExtensions.forEach(function(uuid) {
-            try {
-                enableExtension(uuid);
-            } catch(e) {
-                logExtensionError(uuid, e);
-            }
+            enableExtension(uuid);
         });
     }
 }
