@@ -9,12 +9,12 @@ const St = imports.gi.St;
 const BoxPointer = imports.ui.boxpointer;
 const Main = imports.ui.main;
 
-const MAX_CANDIDATES_PER_PAGE = 16;
+var MAX_CANDIDATES_PER_PAGE = 16;
 
-const DEFAULT_INDEX_LABELS = [ '1', '2', '3', '4', '5', '6', '7', '8',
-                               '9', '0', 'a', 'b', 'c', 'd', 'e', 'f' ];
+var DEFAULT_INDEX_LABELS = [ '1', '2', '3', '4', '5', '6', '7', '8',
+                             '9', '0', 'a', 'b', 'c', 'd', 'e', 'f' ];
 
-const CandidateArea = new Lang.Class({
+var CandidateArea = new Lang.Class({
     Name: 'CandidateArea',
 
     _init: function() {
@@ -128,7 +128,7 @@ const CandidateArea = new Lang.Class({
 });
 Signals.addSignalMethods(CandidateArea.prototype);
 
-const CandidatePopup = new Lang.Class({
+var CandidatePopup = new Lang.Class({
     Name: 'CandidatePopup',
 
     _init: function() {
