@@ -25,12 +25,12 @@ const RemoteMenu = imports.ui.remoteMenu;
 const Main = imports.ui.main;
 const Tweener = imports.ui.tweener;
 
-const PANEL_ICON_SIZE = 16;
-const APP_MENU_ICON_MARGIN = 0;
+var PANEL_ICON_SIZE = 16;
+var APP_MENU_ICON_MARGIN = 0;
 
-const BUTTON_DND_ACTIVATION_TIMEOUT = 250;
+var BUTTON_DND_ACTIVATION_TIMEOUT = 250;
 
-const SPINNER_ANIMATION_TIME = 1.0;
+var SPINNER_ANIMATION_TIME = 1.0;
 
 // To make sure the panel corners blend nicely with the panel,
 // we draw background and borders the same way, e.g. drawing
@@ -83,7 +83,7 @@ function _unpremultiply(color) {
  * this menu also handles startup notification for it.  So when we
  * have an active startup notification, we switch modes to display that.
  */
-const AppMenuButton = new Lang.Class({
+var AppMenuButton = new Lang.Class({
     Name: 'AppMenuButton',
     Extends: PanelMenu.Button,
 
@@ -399,7 +399,7 @@ const AppMenuButton = new Lang.Class({
 
 Signals.addSignalMethods(AppMenuButton.prototype);
 
-const ActivitiesButton = new Lang.Class({
+var ActivitiesButton = new Lang.Class({
     Name: 'ActivitiesButton',
     Extends: PanelMenu.Button,
 
@@ -487,7 +487,7 @@ const ActivitiesButton = new Lang.Class({
     }
 });
 
-const PanelCorner = new Lang.Class({
+var PanelCorner = new Lang.Class({
     Name: 'PanelCorner',
 
     _init: function(side) {
@@ -654,7 +654,7 @@ const PanelCorner = new Lang.Class({
     }
 });
 
-const AggregateLayout = new Lang.Class({
+var AggregateLayout = new Lang.Class({
     Name: 'AggregateLayout',
     Extends: Clutter.BoxLayout,
 
@@ -687,7 +687,7 @@ const AggregateLayout = new Lang.Class({
     }
 });
 
-const AggregateMenu = new Lang.Class({
+var AggregateMenu = new Lang.Class({
     Name: 'AggregateMenu',
     Extends: PanelMenu.Button,
 
@@ -767,7 +767,7 @@ const PANEL_ITEM_IMPLEMENTATIONS = {
     'keyboard': imports.ui.status.keyboard.InputSourceIndicator,
 };
 
-const Panel = new Lang.Class({
+var Panel = new Lang.Class({
     Name: 'Panel',
 
     _init : function() {
@@ -823,12 +823,17 @@ const Panel = new Lang.Class({
     },
 
     _onWindowActorAdded: function(container, metaWindowActor) {
-        let signalId = metaWindowActor.connect('allocation-changed', Lang.bind(this, this._updateSolidStyle));
-        this._trackedWindows.set(metaWindowActor, signalId);
+        let signalIds = [];
+        ['allocation-changed', 'notify::visible'].forEach(s => {
+            signalIds.push(metaWindowActor.connect(s, Lang.bind(this, this._updateSolidStyle)));
+        });
+        this._trackedWindows.set(metaWindowActor, signalIds);
     },
 
     _onWindowActorRemoved: function(container, metaWindowActor) {
-        metaWindowActor.disconnect(this._trackedWindows.get(metaWindowActor));
+        this._trackedWindows.get(metaWindowActor).forEach(id => {
+            metaWindowActor.disconnect(id);
+        });
         this._trackedWindows.delete(metaWindowActor);
         this._updateSolidStyle();
     },
@@ -1155,7 +1160,7 @@ const Panel = new Lang.Class({
     },
 
     _onMenuSet: function(indicator) {
-        if (!indicator.menu || indicator.menu._openChangedId > 0)
+        if (!indicator.menu || indicator.menu.hasOwnProperty('_openChangedId'))
             return;
 
         indicator.menu._openChangedId = indicator.menu.connect('open-state-changed',
