@@ -14,6 +14,7 @@ const Signals = imports.signals;
 const AltTab = imports.ui.altTab;
 const Dialog = imports.ui.dialog;
 const WorkspaceSwitcherPopup = imports.ui.workspaceSwitcherPopup;
+const InhibitShortcutsDialog = imports.ui.inhibitShortcutsDialog;
 const Main = imports.ui.main;
 const ModalDialog = imports.ui.modalDialog;
 const Tweener = imports.ui.tweener;
@@ -33,7 +34,6 @@ var DIM_BRIGHTNESS = -0.3;
 var DIM_TIME = 0.500;
 var UNDIM_TIME = 0.250;
 
-var DISPLAY_REVERT_TIMEOUT = 20; // in seconds - keep in sync with mutter
 var ONE_SECOND = 1000; // in ms
 
 const GSD_WACOM_BUS_NAME = 'org.gnome.SettingsDaemon.Wacom';
@@ -64,7 +64,7 @@ var DisplayChangeDialog = new Lang.Class({
 
         this._wm = wm;
 
-        this._countDown = DISPLAY_REVERT_TIMEOUT;
+        this._countDown = Meta.MonitorManager.get_display_configuration_timeout();
 
         let iconName = 'preferences-desktop-display-symbolic';
         let icon = new Gio.ThemedIcon({ name: iconName });
@@ -712,6 +712,7 @@ var WindowManager = new Lang.Class({
         this._shellwm.connect('filter-keybinding', Lang.bind(this, this._filterKeybinding));
         this._shellwm.connect('confirm-display-change', Lang.bind(this, this._confirmDisplayChange));
         this._shellwm.connect('create-close-dialog', Lang.bind(this, this._createCloseDialog));
+        this._shellwm.connect('create-inhibit-shortcuts-dialog', Lang.bind(this, this._createInhibitShortcutsDialog));
         global.screen.connect('restacked', Lang.bind(this, this._syncStacking));
 
         this._workspaceSwitcherPopup = null;
@@ -1977,6 +1978,10 @@ var WindowManager = new Lang.Class({
         return new CloseDialog.CloseDialog(window);
     },
 
+    _createInhibitShortcutsDialog: function (shellwm, window) {
+        return new InhibitShortcutsDialog.InhibitShortcutsDialog(window);
+    },
+
     _showResizePopup: function(display, show, rect, displayW, displayH) {
         if (show) {
             if (!this._resizePopup)
